<?php
/*
Plugin Name: Minimum Order Quantity and More
Description: Eine Mindestbestellmenge wird erstellt sowie eine Maximalanzahl an unterschiedlichen Produkten dieser Kategorie im Warenkorb.
Version: 1.0
Author: Webdesign OWL
*/

// Add minimum order amount validation
function custom_minimum_order_amount() {
    // Set the minimum order amount
    $minimum_order_amount = 10;

    // Initialize variables
    $total_hauptgerichte_quantity = 0;
    $allowed_different_count = 0;

    // Loop through cart contents to count quantities and unique products
    foreach (WC()->cart->get_cart() as $cart_item) {
        // Check if the product has the category "hauptgerichte"
        if (has_term('hauptgerichte', 'product_cat', $cart_item['product_id'])) {
            $total_hauptgerichte_quantity += $cart_item['quantity'];
        }
    }

    // Check if the total quantity of hauptgerichte is less than the minimum order amount
    if ($total_hauptgerichte_quantity < $minimum_order_amount) {
        // Remove the "Proceed to Checkout" button to prevent checkout
        remove_action('woocommerce_proceed_to_checkout', 'woocommerce_button_proceed_to_checkout', 20);

        // Display a custom message instead
        echo '<div class="woocommerce-error" role="alert">' . sprintf(
            __('Die Mindestbestellmenge beträgt %s Hauptgerichte. Ihre jetztige Menge liegt bei %s Hauptgerichten.', 'your-text-domain'),
            $minimum_order_amount,
            $total_hauptgerichte_quantity
        ) . '</div>';
        return;
    }

    // Set the minimum order amount based on total quantity of hauptgerichte
    $minimum_order_quantities = array(
        10 => 2,
		20 => 2,
        30 => 2,
        40 => 3,
        50 => 3,
        60 => 4,
        70 => 4,
        80 => 5,
        90 => 5,
        100 => 6,
        110 => 6,
        120 => 7,
        130 => 7,
        140 => 8,
        150 => 8,
        160 => 9,
        170 => 9,
        180 => 10,
        190 => 11,
        200 => 12
    );

    // Determine the allowed different count based on the total quantity
    foreach ($minimum_order_quantities as $min_quantity => $different_count) {
        if ($total_hauptgerichte_quantity >= $min_quantity) {
            $allowed_different_count = $different_count;
        }
    }

    // Count the number of different hauptgerichte in the cart
    $different_hauptgerichte = array_filter(
        WC()->cart->get_cart(),
        function ($cart_item) {
            return has_term('hauptgerichte', 'product_cat', $cart_item['product_id']);
        }
    );

    $different_hauptgerichte_count = count(array_unique(array_column($different_hauptgerichte, 'product_id')));

    // Check if the number of different hauptgerichte exceeds the allowed count
    if ($different_hauptgerichte_count > $allowed_different_count) {
        // Remove the "Proceed to Checkout" button to prevent checkout
        remove_action('woocommerce_proceed_to_checkout', 'woocommerce_button_proceed_to_checkout', 20);

        // Display a custom message instead
        echo '<div class="woocommerce-error" role="alert">' . sprintf(
            __('Bei insgesamt %s Hauptgerichten in Ihrem Warenkorb dürfen Sie nur %s verschiedene Hauptgerichte auswählen.', 'your-text-domain'),
            $total_hauptgerichte_quantity,
            $allowed_different_count
        ) . '</div>';
    }
}

// Hook into the 'woocommerce_before_cart_table' action
add_action('woocommerce_before_cart_table', 'custom_minimum_order_amount');